#
# spec file for package python-matplotlib
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
%define skip_python2 1
# Not doing tests because they take too long
# The tests also pull in dependencies of all backends done in pure python
%bcond_with tests
Name:           python3-matplotlib
Version:        2.2.5
Release:        150400.13.67
Summary:        Plotting Library for Python
License:        SUSE-Matplotlib
Group:          Development/Libraries/Python
URL:            https://matplotlib.org
Source0:        https://files.pythonhosted.org/packages/source/m/matplotlib/matplotlib-%{version}.tar.gz
Source1:        matplotlib-setup.cfg
# Needed for all versions of python
BuildRequires:  %{python_module Cycler >= 0.10}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module kiwisolver}
BuildRequires:  %{python_module numpy >= 1.7.1}
BuildRequires:  %{python_module numpy-devel >= 1.7.1}
BuildRequires:  %{python_module pyparsing > 2.1.6}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.10}
# WebAgg dependencies
BuildRequires:  %{python_module tornado}
BuildRequires:  c++_compiler
BuildRequires:  fdupes
BuildRequires:  pkgconfig
# Python 2 only
BuildRequires:  python-functools32
BuildRequires:  python-rpm-macros
BuildRequires:  python-subprocess32
# tk dependencies via tcl
BuildRequires:  tcl
BuildRequires:  pkgconfig(freetype2) >= 2.3
BuildRequires:  pkgconfig(libpng) >= 1.2
BuildRequires:  pkgconfig(tcl)
# End of backend dependencies
Requires:       python3-Cycler >= 0.10
Requires:       python3-kiwisolver >= 1.0.1
Requires:       python3-numpy >= 1.7.1
Requires:       python3-pyparsing > 2.1.6
Requires:       python3-python-dateutil >= 2.1
Requires:       python3-pytz
Requires:       python3-six >= 1.10
Recommends:     %{python_flavor}-Pillow
Recommends:     ghostscript
Recommends:     libxml2-tools
Recommends:     poppler-tools
Provides:       python3-matplotlib-gtk = %{version}
Obsoletes:      python3-matplotlib-gtk < %{version}
# needed for testing
%if %{with tests}
# cairo dependencies
BuildRequires:  %{python_module cairocffi}
# GTK3 dependencies
BuildRequires:  %{python_module gobject}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module python-dateutil >= 2.1}
# Qt5 dependencies
BuildRequires:  %{python_module qt5}
# tk dependencies
BuildRequires:  %{python_module tk}
# latex dependencies
BuildRequires:  ghostscript
BuildRequires:  inkscape
BuildRequires:  poppler-tools
# Wx dependencies (currently Python 2 only)
BuildRequires:  python-wxWidgets >= 3
BuildRequires:  qhull-devel >= 2003.1
BuildRequires:  texlive-dvipng
BuildRequires:  texlive-latex
BuildRequires:  texlive-sfmath
BuildRequires:  texlive-tex
# X server needed for Qt4/Qt5 tests
BuildRequires:  xorg-x11-Xvfb
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  tex(8a.enc)
BuildRequires:  tex(helvet.sty)
BuildRequires:  tex(phvr7t.tfm)
BuildRequires:  tex(pncr7t.tfm)
BuildRequires:  tex(psfrag.sty)
BuildRequires:  tex(type1cm.sty)
BuildRequires:  tex(ucs.sty)
%endif
%ifpython2
Requires:       python3-backports.functools_lru_cache
Requires:       python3-functools32
Requires:       python3-subprocess32
%endif
%if 0%{?suse_version} >= 1500
Recommends:     (%{python_flavor}-matplotlib-tk if tk)
%else
Recommends:     python3-matplotlib-tk
%endif
%ifpython2
Provides:       %{oldpython}-matplotlib-gtk = %{version}
Obsoletes:      %{oldpython}-matplotlib-gtk < %{version}
%endif
%python_subpackages

%description
matplotlib is a python 2D plotting library which produces publication
quality figures in a variety of hardcopy formats and interactive
environments across platforms. matplotlib can be used in python
scripts, the python and ipython shell (ala matlab or mathematica), web
application servers, and six graphical user interface toolkits.

%package cairo
Summary:        Cairo backend for %{name}
License:        SUSE-Matplotlib
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       python3-cairocffi

%description cairo
This package includes the non-interactive Cairo-based backend
for the %{name} plotting package

%package gtk3
Summary:        GTK3 backends for %{name}
License:        BSD-2-Clause
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       %{name}-cairo = %{version}
Requires:       python3-gobject

%description gtk3
This package includes the GTK3-based gtk3, gtk3agg, and
gtk3cairo backends for the %{name} plotting package

%package latex
Summary:        Allow rendering latex in %{name}
License:        BSD-2-Clause
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       texlive-dvipng
Requires:       texlive-latex
Requires:       texlive-sfmath
Requires:       texlive-tex

%description latex
This package allows %{name} to display latex in plots
and figures.

%package qt5
Summary:        Qt5 backend for %{name}
License:        BSD-2-Clause
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       python3-qt5

%description qt5
This package includes the Qt5-based pyqt5 backend
for the %{name} plotting package

%package tk
Summary:        Tk backend for %{name}
License:        BSD-2-Clause
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       python3-tk
Requires:       tcl >= 8.3

%description tk
This package includes the Tk-based tkagg backend
for the %{name} plotting package

%package web
Summary:        Web backend for %{name}
License:        BSD-2-Clause
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       python3-tornado

%description web
This package includes the browser-based webagg backend
for the %{name} plotting package

%package wx
Summary:        WxWidgets backend for %{name}
License:        BSD-2-Clause
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       python3-wxWidgets >= 2.8

%description wx
This package includes the wxWidgets-based wxagg backend
for %{name} plotting package

%prep
%setup -q -n matplotlib-%{version}
chmod -x lib/matplotlib/mpl-data/images/*.svg
find examples lib/matplotlib lib/mpl_toolkits/mplot3d -type f -name "*.py" -exec sed -i "s|#!\/usr\/bin\/env python||" {} \;
find examples lib/matplotlib lib/mpl_toolkits/mplot3d -type f -name "*.py" -exec sed -i "s|#!\/usr\/bin\/python||" {} \;
cp %{SOURCE1} ./setup.cfg

%if %{without tests}
sed -i -e 's/tests = .*/tests = False/' ./setup.cfg
%else
# raise tolerance for changes due to freetype 2.6/2.7 rendering differences
sed -i -e 's/\(image_comparison.*\)tol=0/\1tol=0.310/' lib/matplotlib/testing/decorators.py # default
sed -i -e 's/tol=0.002/tol=0.009/' lib/matplotlib/tests/test_streamplot.py
sed -i -e 's/tol=0.*)/tol=0.012)/' lib/matplotlib/tests/test_png.py
# image rotation is broken, investigate
sed -i -e 's/\(image_comparison.*rotate_image.*\)/\1 tol=150,/' lib/matplotlib/tests/test_image.py
%endif

%build
export XDG_RUNTIME_DIR=/tmp
%python_build

%install
export XDG_RUNTIME_DIR=/tmp
%python_install
%{python_expand %fdupes %{buildroot}%{$python_sitearch}
$python -m compileall -d %{$python_sitearch} %{buildroot}%{$python_sitearch}/matplotlib/backends/qt_editor/
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitearch}/matplotlib/backends/qt_editor/
%fdupes %{buildroot}%{$python_sitearch}/matplotlib/backends/qt_editor/
}

%if %{with tests}
%check
export DISPLAY=:42
%{_bindir}/Xvfb :42 -screen 0 1024x768x24 >& /tmp/Xvfb.log &
trap "kill $! || true" EXIT
%python_expand PYTHONPATH=%{buildroot}%{$python_sitearch} $python ./tests.py --no-network --recursionlimit=5000
%endif

%files %{python_files}
%doc README.rst
%doc examples/
%license LICENSE/
%license doc/users/license.rst
%{python_sitearch}/matplotlib/
%{python_sitearch}/matplotlib-%{version}-py*.egg-info
%{python_sitearch}/matplotlib-%{version}-py*-nspkg.pth
%{python_sitearch}/mpl_toolkits
%{python_sitearch}/pylab.py*
%pycache_only %{python_sitearch}/__pycache__/pylab.*
%exclude %{python_sitearch}/matplotlib/backends/backend_cairo.*
%exclude %{python_sitearch}/matplotlib/backends/backend_gtk3.*
%exclude %{python_sitearch}/matplotlib/backends/backend_gtk3agg.*
%exclude %{python_sitearch}/matplotlib/backends/backend_gtk3cairo.*
%exclude %{python_sitearch}/matplotlib/backends/backend_qt4.py*
%exclude %{python_sitearch}/matplotlib/backends/backend_qt4agg.py*
%exclude %{python_sitearch}/matplotlib/backends/backend_qt5.*
%exclude %{python_sitearch}/matplotlib/backends/backend_qt5agg.*
%exclude %{python_sitearch}/matplotlib/backends/backend_tkagg.*
%exclude %{python_sitearch}/matplotlib/backends/backend_webagg.*
%exclude %{python_sitearch}/matplotlib/backends/backend_webagg_core.*
%exclude %{python_sitearch}/matplotlib/backends/qt_compat.*
%exclude %{python_sitearch}/matplotlib/backends/qt_editor/
%exclude %{python_sitearch}/matplotlib/backends/tkagg.*
%exclude %{python_sitearch}/matplotlib/backends/web_backend/
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_cairo.*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_gtk3.*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_gtk3agg.*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_gtk3cairo.*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_qt4.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_qt4agg.*.py*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_qt5.*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_qt5agg.*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_tkagg.*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_webagg.*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_webagg_core.*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/qt_compat.*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/tkagg.*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/backend_wx*
%exclude %{python_sitearch}/matplotlib/backends/__pycache__/wx_compat.*
%exclude %{python_sitearch}/matplotlib/backends/backend_wx.py*
%exclude %{python_sitearch}/matplotlib/backends/backend_wxagg.py*
%exclude %{python_sitearch}/matplotlib/backends/wx_compat.py*

# Dummy package to pull in latex dependencies.
%files %{python_files latex}
%license LICENSE/
%license doc/users/license.rst

%files %{python_files cairo}
%license LICENSE/
%license doc/users/license.rst
%{python_sitearch}/matplotlib/backends/backend_cairo.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_cairo.*.py*

%files %{python_files gtk3}
%license LICENSE/
%license doc/users/license.rst
%{python_sitearch}/matplotlib/backends/backend_gtk3.py*
%{python_sitearch}/matplotlib/backends/backend_gtk3agg.py*
%{python_sitearch}/matplotlib/backends/backend_gtk3cairo.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_gtk3.*.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_gtk3agg.*.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_gtk3cairo.*.py*

%files %{python_files qt5}
%license LICENSE/
%license doc/users/license.rst
%{python_sitearch}/matplotlib/backends/backend_qt5.py*
%{python_sitearch}/matplotlib/backends/backend_qt5agg.py*
%{python_sitearch}/matplotlib/backends/qt_compat.py*
%{python_sitearch}/matplotlib/backends/qt_editor/
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_qt5.*.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_qt5agg.*.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/qt_compat.*.py*

%files %{python_files tk}
%license LICENSE/
%license doc/users/license.rst
%{python_sitearch}/matplotlib/backends/backend_tkagg.py*
%{python_sitearch}/matplotlib/backends/tkagg.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_tkagg.*.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/tkagg.*.py*

%files %{python_files web}
%license LICENSE/
%license doc/users/license.rst
%{python_sitearch}/matplotlib/backends/backend_webagg.py*
%{python_sitearch}/matplotlib/backends/backend_webagg_core.py*
%{python_sitearch}/matplotlib/backends/web_backend/
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_webagg.*.py*
%pycache_only %{python_sitearch}/matplotlib/backends/__pycache__/backend_webagg_core.*.py*

%files %{python_files wx}
%license LICENSE/
%license doc/users/license.rst
%{python_sitearch}/matplotlib/backends/wx_compat.py*
%{python_sitearch}/matplotlib/backends/backend_wx.py*
%{python_sitearch}/matplotlib/backends/backend_wxagg.py*

%changelog
* Tue Apr 12 2022 mcepl@suse.com
- Clean up spec and correct to proper single-spec SPEC
  file. Fixes FTBFS (bsc#1198319).
* Mon Apr 19 2021 mcepl@suse.com
- Fix dependencies to explicit python3-* ones (bsc#1184340).
* Wed May 20 2020 tchvatal@suse.com
- Remove Qt4 backend as we don't want to ship Qt4 anymore
* Mon May 18 2020 tchvatal@suse.com
- Update version to 2.2.5:
  * Latest 2.x series that supports python2 (we have 3x on TW)
- Make it agnostic between SLE and openSUSE jsc#SLE-11752
  * Same change done to 3.x series in TW
* Tue Aug 14 2018 toddrme2178@gmail.com
- Update to version 2.2.3
  * Fix import failure on BSD systems
  * Fix import errors in Qt shims for PyQt5 5.11 and PyQt4 4.12
  * Fix import errors if bz2 module is not in standard library
  * Fix overflow in _path.h
  * Fix infinite recursion in transform repr
  * Fix bug with XKCD style
  * Remove unsafe usage of Popen
* Sat Jun  2 2018 hpj@urpla.net
- don't use any lua expressions for suse_version < 1500
* Fri Jun  1 2018 dimstar@opensuse.org
- Only recommend python-matplotlib-tk if tk is already flagged for
  installation. On most systems there is no reason to have tk
  available (those UIs are out of date and not well perceived
  anyway).
* Tue May 15 2018 tbechtold@suse.com
- Add missing Requires for python-backports.functools_lru_cache (boo#1074491)
* Thu May 10 2018 toddrme2178@gmail.com
- Fix building on SLE which doesn't have qhull.
* Sat Mar 17 2018 arun@gmx.de
- update to version 2.2.2:
  * v2.2.1 did not actually restore matplotlib.verbose.
- changes from version 2.2.1:
  * This release fixes a number of critical bugs:
    + restores matplotlib.verbose (fixing embedding in pycharm)
    + preserve precision when color mapping small portions of data
    with extreme outliers
    + fixes saving long movies with ffmpeg
    + fixes UnbourdLocal error in contour labeling
    + fixes import failure on python 3.4.0 and 3.4.1
    + fixes compile time failures with clang on 32bit platforms
    + fixes an icon in the Tk backends
    + fixes several issues with Tables
    + fixes expanding offset boxes with tight_layout
    + revert changes to the font caching to avoid a possible bug in
    backports.lru_cache
    + numerous docstring and documentation fixes
  * We have reverted the deprecation of `font_manager.TempCache`.
* Thu Mar  8 2018 arun@gmx.de
- specfile:
  * require kiwisolver
  * update required version for dateutil
- update to version 2.2.0:
  * The first release of the v2.2 LTS series and the last version of
    Matplotlib to support python2.  There will be bug-fix release for
    this series until 2020.
  * This release includes new features including:
    + An experimental constrained layout manager
    + Color blind friendly color map (cividis) and color cycle
    (tableau-colorblind10)
    + native support for numpy.datetime64 types
    + animated gif writing via pillow
    + TkAgg now works with pypy
    + cairo based backends for Qt, Tk, and WX
  * There are several API changes in this release:
    + To support the constrained layout Matplotlib has a new required
    dependency (kiwisolver).
    + The `matplotlib.finance` module has been removed, development
    has moved to a stand-alone project.
* Tue Jan 30 2018 rolf@rotkraut.de
- Update versions of required packages.
* Sun Jan 28 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 2.1.2:
  * This release fixes a number of critical bugs:
    + fix a typo in mlab.cohere which yielded incorrect results
    + allow nonposx / nonposy to pass through loglog
    + fix color comparisons when finding handles with legend
    + fixes a recursive draw bug and a major performance regression in
    Qt5Agg backend
    + fix a re-draw bug in WxAgg
    + fix image scaling with high-bit depth integers
    + revert the busy-cursor
* Wed Jan 17 2018 thod_@gmx.de
- dependency changed to python-six >= 1.10
  (see "site-packages/matplotlib/__init__.py", line 187)
* Sat Dec 16 2017 arun@gmx.de
- update to version 2.1.1:
  * The first and only planned bug-fix release for the 2.1 series.
  * This release include many bug and documentation fixes.  Highlights
    are:
    + change default logscale behavior to clip
    + fixed webagg import errors
    + tweaks to polar ticks
    + fixed exception when guessing afm family names
    + update manifest to include all doc files
    + improve masked array handling in pcolormesh
    + fix segfault from reading invalid png
    + fix blocking_input
    + fix bug resulting in huge multi-page pdf files
    + make `show` in nbagg take args as other backends do
    + several fixes to OSX backend
    + restore positional arg handling on Figure.legend
    + fix bugs in interactive navigation
    + fix issues when panning with invalid limits
    + fix bug with fully masked arrays passed to imshow
* Thu Oct 26 2017 toddrme2178@gmail.com
- Update to version 2.1.0
  + New features
  * String categorical values
  * Interactive JS widgets for animation
  * Enhancements to polar plot
  * Figure class now has subplots method
  * Metadata savefig keyword argument
  * Busy Cursor
  * PolygonSelector
  * Added matplotlib.ticker.PercentFormatter
  * Reproducible PS, PDF and SVG output
  * Orthographic projection for mplot3d
  * voxels function for mplot3d
  + Improvements
  * Add capstyle and joinstyle attributes to Collection
  * CheckButtons widget get_status function
  * Add fill_bar argument to AnchoredSizeBar
  * Annotation can use a default arrow style
  * Barbs and Quiver Support Dates
  * Hexbin default line color
  * Figure.legend() can be called without arguments
  * Multiple legend keys for legend entries
  * New parameter clear for :func:`~matplotlib.pyplot.figure`
  * Specify minimum value to format as scalar for LogFormatterMathtext
  * New quiverkey angle keyword argument
  * Colormap reversed method
  * Artist.setp (and pyplot.setp) accept a file argument
  * streamplot streamline generation more configurable
  * Axis.set_tick_params now responds to rotation
  * Shading in 3D bar plots
  * New which Parameter for autofmt_xdate
  * New Figure Parameter for subplot2grid
  * Interpolation in fill_betweenx
  * New keyword argument sep for EngFormatter
  * Extend MATPLOTLIBRC behavior
  * density kwarg to hist
  + Internals
  * New TransformedPatchPath caching object
  * Abstract base class for movie writers
  * Stricter validation of line style rcParams
  + Performance
  * Path simplification updates
  * Implement intersects_bbox in c++\
- Remove upstream-included patches:
  * 0001-Fix-include-path-for-system-libqhull.patch
  * 0001-Allow-divmod-to-be-overridden-by-num.patch
  * 166a14473272_Fix-contour-colour-level-determination.patch
  * 97e170d2fc2c_Pass-integers-to-np_linspace.patch
* Mon Oct  9 2017 stefan.bruens@rwth-aachen.de
- Fix/enhance build with tests:
  - set PYTHONPATH, otherwise tests will not find the python
    modules installed to the buildroot
  - Add BuildRequires for several tex styles/resources
  - Add BuildRequires: xorg-x11-Xvfb, needed for Qt backend tests
  - Remove python-Pillow, tests are only using png, not e.g jpeg
  - increase image compare tolerance, our Freetype 2.7 renders
    slightly different to the baseline FT 2.6
  - Add upstream 0001-Allow-divmod-to-be-overridden-by-num.patch,
    to cope with numpy 1.13 changes
  - Add upstream 166a14473272_Fix-contour-colour-level-determination.patch
  - Add upstream 97e170d2fc2c_Pass-integers-to-np_linspace.patch
* Mon Oct  9 2017 stefan.bruens@rwth-aachen.de
- Also remove runtime-only python-tk dependecy from BuildRequires:
* Sat Oct  7 2017 stefan.bruens@rwth-aachen.de
- Rebase the matplotlib setup.cfg on upstream version
- Guard several BuildRequires: which are not necessary for building
  with the "tests" conditional, most backends are pure python
- Do not install/package baseline images only necessary for tests,
  shrinks the main package by 60 MByte
* Thu Aug 10 2017 toddrme2178@gmail.com
- Update to version 2.0.2
  Critical bug fixes for 2.0.1
  * fixed Qt4 support
  * fixed LogFormatter
  * fixed hatched artists in legends
  * fixed segfault with large images
- Update to version 2.0.1
  Bug fix release for 2.0.x series
  This release includes bug fixes, documentation updates and one major change.
  + API
  * Do not clip the linewidth used for dash pattern scaling.  This is
    an API change, but is a major improvement.
  * Deprecate 'vega' color names in favor of 'tab'.
  + Bug Fixes
  * Hatching color follows edge color again.
  * Fixes a critical bug with masked images.
  * Improved high-dpi support for Qt5.
  * Log ticking no never skip minor ticks
  * Do not skip points surrounded by nan/inf in vector outputs.
- Disable backends on releases that don't support them.
* Thu Jul 13 2017 stefan.bruens@rwth-aachen.de
- Add 0001-Fix-include-path-for-system-libqhull.patch
  Avoid falling back to outdated bundled version
* Sun Apr 30 2017 toddrme2178@gmail.com
- Restore qt4 backend since qt4 still has maintained,
  python3-comptible python bindings.
- Provide/obsolete gtk backend to avoid conflicts.
  It doesn't have maintained, python3-compatible python bindings.
* Mon Mar 27 2017 toddrme2178@gmail.com
- Implement single-spec version
- Drop old qt4 and gtk2 backends
- Drop unmaintained qt designer widget
* Fri Mar 10 2017 toddrme2178@gmail.com
- Fix file list
* Fri Jan 20 2017 toddrme2178@gmail.com
- Add python-functools32 dependency.
* Tue Jan 17 2017 toddrme2178@gmail.com
- update to version 2.0.0
  + Highlights include:
  * 'viridis' is default color map instead of jet.
  * Modernized the default color cycle.
  * Many more functions respect the color cycle.
  * Line dash patterns scale with linewidth.
  * Change default font to DejaVu, now supports most Western alphabets (including Greek, Cyrillic and Latin with diacritics), math symbols and emoji out of the box.
  * Faster text rendering.
  * Improved auto-limits.
  * Ticks out and only on the right and bottom spines by default.
  * Improved auto-ticking, particularly for log scales and dates.
  * Improved image support (imshow respects scales and eliminated a class of artifacts).
* Fri Dec  2 2016 sbahling@suse.com
- update to version 1.5.3
  * Changed default autorange behavior in boxplots (introduced with
    1.5.2)
- Change BuildRequires and Recommends from python-Pillow to
  python-imaging to allow for SLE 12 builds. (python-Pillow
  provides python-imaging)
* Sat Jul 30 2016 jengelh@inai.de
- Make use of wxWidgets 3
* Fri Feb 26 2016 tbechtold@suse.com
- Require python-python-dateutil. package was renamed
* Mon Jan 11 2016 toddrme2178@gmail.com
- Update to version 1.5.1:
  First bug fix release for 1.5.x series.
* Wed Dec  2 2015 egeorget@openmailbox.org
- Enabled qt5 on Leap 42.1
- Enabled wx on Leap 42.1
* Wed Nov 25 2015 p.drouand@gmail.com
- Drop agg-devel dependenxy; useless
* Fri Oct 30 2015 toddrme2178@gmail.com
- Add new python-Cycler dependency
* Fri Oct 30 2015 toddrme2178@gmail.com
- Update to 1.5.0
  * Auto-redraw using the object-oriented API.
  * Most plotting functions now support labeled data API.
  * Color cycling has extended to all style properties.
  * Four new perceptually uniform color maps, including the
    soon-to-be default 'viridis'.
  * More included style sheets.
  * Many small plotting improvements.
  * Proposed new framework for managing the GUI toolbar and tools.
* Wed Jul  1 2015 toddrme2178@gmail.com
- Disable qt5 on SLE 12
- Disable wx on SLE 11 and 12
- Disable latex and gtk3 on SLE 11
- Don't require texlive-sfmath on SLE 12
- Disable qt5 on ppc and arm
- Depend on libxml2 instead of libxml2-tools
* Thu May 21 2015 toddrme2178@gmail.com
- Fix installed files
* Mon Mar  2 2015 toddrme2178@gmail.com
- specfile:
  * update url
  * update source url to point to pypi
- update to version 1.4.3:
  * Many bugs are fixed including:
  - fixing drawing of edge-only markers in AGG
  - fix run-away memory usage when using %%inline or saving with a
    tight bounding box with QuadMesh artists
  - improvements to wx and tk gui backends
  * Additionally the webagg and nbagg backends were brought closer to
    feature parity with the desktop backends with the addition of
    keyboard and scroll events thanks to Steven Silvester.
* Mon Oct 27 2014 toddrme2178@gmail.com
- Update to 1.4.2.  This is a bug-fix release for the 1.4 series.
  - corrected boxplot in pyplot.py
  - added extra paths to default search paths for freetype
* Mon Oct 20 2014 toddrme2178@gmail.com
- Update to 1.4.1.  This is a bug-fix release for the 1.4 series.
  - reverts the changes to interactive plotting so ion will work as
    before in all cases fixed boxplot regressions
  - fixes for finding freetype and libpng
  - sundry unicode fixes (looking up user folders, importing
    seaborn/pandas/networkx with macosx backend)
  - nbagg works with python 3 + new font awesome
  - fixed saving dialogue in QT5
* Thu Sep 18 2014 toddrme2178@gmail.com
- Create subpackage to pull in latex dependencies so they are more
  visible to users.
- Comment out testing BuildRequires since we aren't doing testing.
  We aren't doing testing because it takes a long time and a lot
  of packages depend on matplotlib, so it slows down the build
  process for python packages too much.
* Wed Sep 17 2014 jmatejek@suse.com
- downgrade Recommends for texlive (and other big packages) to Suggests
  (this means texlive is not pulled in by default zypper settings)
* Wed Sep 10 2014 toddrme2178@gmail.com
- Dependency and spec file cleanups
- Remove unneeded use-setuptools.diff
* Thu Aug 28 2014 dmueller@suse.com
- adjust python-tz buildrequires to match runtime requires (python-pytz)
* Wed Aug 27 2014 toddrme2178@gmail.com
- Add new python-cairocffi dependency.  This is the recommended
  dependency for the cairo backend upstream.
- Split out the cairo backend into its own subpackage.  It is no
  longer tied to gtk, so people can use it on its own without
  pulling in any gtk dependencies.
- Fixed issues with qt.  The qt5 backend is actually a generic
  qt backend, which the qt4 backend depends on.  So it needs to be
  available for the qt4 backend to work at all.  However, we need
  to pull in the python-qt5 package to make it work, and that
  package is only available for openSUSE > 13.1.  So we need to
  split the generic qt stuff, including the qt5 stuff, into a
  package both the qt4 and qt5 backends can depend on, and then
  create a stub qt5 package that just pulls in python-qt5
- Reorganized some other backend packages based on backend changes
* Tue Aug 26 2014 toddrme2178@gmail.com
- Update to 1.4.0
  * New colormap for red-green color blind users
  * Documentation changes
  - Phil Elson rewrote of the documentation and userguide for both
    Legend and PathEffects.
  * New plotting features
  - Power-law normalization
  - Fully customizable boxplots
  - Support for datetime axes in 2d plots
  - Support for additional spectrum types
  - Support for detrending and windowing 2D arrays in mlab
  - Support for strides in mlab
  - Formatter for new-style formatting strings
  - Consistent grid sizes in streamplots
  - Get a list of all tick labels (major and minor)
  - Separate horizontal/vertical axes padding support in ImageGrid
  - Support for skewed transformations
  - Support for specifying properties of wedge and text in pie
    charts.
  - Fixed the direction of errorbar upper/lower limits
  - More consistent add-object API for Axes
  - Violin Plots
  - More `markevery` options to show only a subset of markers
  - Added size related functions to specialized `Collections`
  - Fixed the mouse coordinates giving the wrong theta value in
    Polar graph
  - Simple quiver plot for mplot3d toolkit
  - polar-plot r-tick locations
  * Date handling
  - n-d array support for date conversion
  * Configuration (rcParams)
  - 'savefig.transparent' added
  - 'axes.titleweight'
  - 'axes.formatter.useoffset' added
  * XDG compliance
  - Matplotlib now looks for configuration files (both rcparams and
    style) in XDG compliant locations.
  * 'style' package added
  - You can now easily switch between different styles using the
    new 'style' package
  * Backends
  - Qt5 backend added
  - Qt4 backend
    + Rudolf Höfler changed the appearance of the subplottool.
    + In the figure options dialog one can now choose to
    (re-)generate a simple automatic legend.
    + Interactive performance of the Qt4 backend has been
    dramatically improved under windows.
    + The mapping of key-signals from Qt to values matplotlib
    understands was greatly improved (For both Qt4 and Qt5).
  - Cairo backends
    +  The Cairo backends are now able to use the cairocffi
    bindings, which are more actively maintained than the pycairo
    bindings.
  - Gtk3Agg backend
    +  The Gtk3Agg backend now works on Python 3.x, if the cairocffi
    bindings are installed.
  - PDF backend
    +  Added context manager for saving to multi-page PDFs.
  * Text
  - Text URLs supported by SVG backend
  - Anchored sizebar font
  * Sphinx extensions
  - The context directive in the plot_directive Sphinx extension
    can now accept an optional reset setting, which will cause the
    context  to be reset.
  * Widgets
  - Span Selector
  * Added an option span_stays to SpanSelector which makes the
    selector rectangle stay on the axes after you release the
    mouse.
  * GAE integration
  - Matplotlib will now run on google app engine.
- Added python-qt5 backend on openSUSE > 13.1
- Spec file cleanups
* Wed Jul 16 2014 toddrme2178@gmail.com
- Set dummy XDG_RUNTIME_DIR to fix building on openSUSE:Factory
* Thu Apr 10 2014 dmueller@suse.com
- install LICENSE directory and fix license tag
* Wed Apr  9 2014 dmueller@suse.com
- add use-setuptools.diff: build against old setuptools as well
* Fri Mar 28 2014 speilicke@suse.com
- Package doc/users/license.rst
* Mon Mar 17 2014 i@marguerite.su
- fix bnc#863451
- added windowing.* to python-matplotlib-tk
- It's windowing instead of Windows, a module required by tk backend
* Sat Mar  8 2014 bwiedemann@suse.com
- Recommend python-matplotlib-tk because it is the default config
* Thu Jan  9 2014 dmueller@suse.com
- remove qt4/designer subpackages for SLE11, as those can
  not be installed without additional updates on a SLES+SDK system
* Thu Nov 14 2013 toddrme2178@gmail.com
- Enable all backends
- Split most backends into separate packages
- Update dependencies
- Add many optional dependencies
- Make %%setup.py quiet
* Thu Oct 24 2013 speilicke@suse.com
- Update to version 1.3.1:
  + Many changes
* Thu Aug 29 2013 jmatejek@suse.com
- add Requires: python-pyparsing
  (the pyparsing module is required for mathtext rendering)
* Wed Aug 21 2013 highwaystar.ru@gmail.com
- update to 1.3.0
- New features:
  * xkcd-style sketch plotting
  * New eventplot plot type
  * Triangular grid interpolation
  * Baselines for stackplot
  * Rectangular colorbar extensions
  * Calling subplot() without arguments
- Drawing:
  * Independent alpha values for face and edge colors
  * Path effects on lines
  * Easier creation of colormap and normalizer for levels with colors
  * Full control of the background color
  * Improved bbox_inches="tight" functionality
  * Initialize a rotated rectangle
- Text:
  * Anchored text support
  * Better vertical text alignment and multi-line text
  * Left and right side axes titles
  * Improved manual contour plot label positioning
- Configuration (rcParams)
  * Quickly find rcParams
  * Changes to font rcParams
- Backends
  * WebAgg backend
  * Remember save directory
- Documentation and examples:
  * Numpydoc docstrings
  * Example reorganization
  * Examples now use subplots()
- Infrastructure
  * Housecleaning
  * New setup script
  * XDG base directory support
  * Catch opening too many figures using pyplot
- for API changes see
  http://matplotlib.org/api/api_changes.html#changes-in-1-3
- removed patches needed for python3 package
* Mon Nov 12 2012 highwaystar.ru@gmail.com
- update to 1.2.0
  * Python 3.x support
  * PGF/TikZ backend
  * Locator interface
  * Tri-Surface Plots
  * Control the lengths of colorbar extensions
  * Figures are picklable
  * Set default bounding box in matplotlibrc
  * New Boxplot Functionality
  * New RC parameter functionality
  * Streamplot
  * New hist functionality
  * Updated shipped dependencies
  * Face-centred colors in tripcolor plots
  * Hatching patterns in filled contour plots, with legends
- python3 package added
* Tue Aug 21 2012 highwaystar.ru@gmail.com
- bugfix upstream release 1.1.1
* Thu Apr 26 2012 toddrme2178@gmail.com
- Remove configobj buildrequires, all configobj files should have
  been removed from matplotlib years ago
* Tue Mar 20 2012 toddrme2178@gmail.com
- Fix Qt Designer plugin directories
* Fri Mar 16 2012 toddrme2178@gmail.com
- Cleaned up spec file formatting
- Removed tests for obsolete openSUSE versions
- Added Qt Designer plugin from Python(x,y) project
* Tue Jan 10 2012 kukuk@suse.de
- Fix spec file for SLE11 (Group entries did go lost)
* Wed Dec 14 2011 highwaystar.ru@gmail.com
- update to 1.1.0
  * module for drawing sankey diagrams;
  * environment for creating animated graphics – module animation;
  * automated positioning charts, labels, and axes on the canvas – a
  team tight_layout () will distribute them so that they are not
  people came to each other;
  * Work on integration with PySide, although functional is still
    in the beta-version and it is recommended to continue using
    PyQt4;
  * improved mapping and positioning of the legend;
  * simplified work with three-dimensional graphs (module mplot3d),
  also significantly expanded and updated documentation on mplot3d;
  * uniform markers;
  * completely removed the old module support Numerix, now all
  users must use Numpy;
  * fixes some bugs.
- removed patches that now upstream
* Thu Dec  8 2011 coolo@suse.com
- fix license to be in spdx.org format
* Tue Oct 11 2011 jmatejek@suse.com
- fix build failing because Tkinter has a faulty __version__
* Mon Aug 15 2011 ro@suse.de
- fix build for platform == linux3
* Mon Jan 24 2011 toddrme2178@gmail.com
- new version 1.0.1
  This is a bugfix release:
  + Fixed error with Hammer projection.
  + Fixed the placement and angle of axis labels in 3D plots.
  + New rc parameters examples.download and examples.directory
    allow bypassing the download mechanism in get_sample_data.
  + Change Axis.set_view_interval() so that when updating an
    existing interval, it respects the orientation of that
    interval, and can enlarge but not reduce the interval.
  + Handle NaN's correctly in path analysis routines.
  + Fix bug in patch alpha handling, and in bar color kwarg
  + Return Qt4's default cursor when leaving the canvas
- cleanup specfile
* Wed Dec 29 2010 sbrabec@suse.cz
- Compile with wxWidgets (STL variant).
* Sat Dec 11 2010 coolo@novell.com
- remove buildrequire on libstdc++
* Sat Jul 17 2010 werner.ho@gmx.de
- new version 1.0.0
* Sat Oct 10 2009 werner.ho@gmx.de
- new version 0.99.1.1
- config file added (seen at home:ocefpaf project)
* Fri Dec 19 2008 lars@linux-schulserver.de
- Update to 0.98.5.2
  + Fix bug where a line with NULL data limits prevents
    subsequent data limits from calculating correctly
  + Major documentation generator changes
  + Fixed dpi-dependent behavior of Legend and fancybox in Text
  + Fix \$ in non-math text with usetex off
  + Fix anti-aliasing when auto-snapping
  + Fix grid lines not moving correctly during pan and zoom
  + Fixed warning in hist() with numpy 1.2
  + Removed the prints in the set_*style commands.  Return the
    list of pprinted strings instead
- 10.2 is gone: remove specific fixes for this distribution
* Mon Nov 24 2008 werner.ho@gmx.de
- replaced scipy by numpy as build requirement
* Wed Aug 20 2008 werner.ho@gmx.de
- removed python-scipy from the requirements list
- added python-dateutil to the requirements list
- added python-pytz to the requirements list
* Sat Aug  9 2008 werner.ho@gmx.de
- new major version 0.98.3
* Tue Aug  5 2008 werner.ho@gmx.de
- new version 0.91.4
* Tue Jul 15 2008 andrea@opensuse.org
- fixed spec file adding missing buildrequires
- made rpmlint happyer
* Fri Jun  6 2008 werner.ho@gmx.de
- new version 0.91.3
* Thu Jan 31 2008 werner.ho@gmx.de
- new version 0.91.2
* Thu Dec  6 2007 werner.ho@gmx.de
- added configobj as an extra requirement
- thus matplotlib will not provide configobj
* Sat Dec  1 2007 werner.ho@gmx.de
- new version 0.91.1
- removed build patches, as the build system has been changed
* Fri Sep  7 2007 werner.ho@gmx.de
- fixed build issus of openSUSE 10.3
* Sat Jun  2 2007 werner.ho@gmx.de
- new version 0.90.1
- added enable_BUILD_WXAGG.patch
* Wed Mar 21 2007 werner.ho@gmx.de
- removed X-server patches, use Xvfb instead
- created extra wx and tk packages
* Mon Mar 19 2007 werner.ho@gmx.de
- default backend is GTKAgg now
- TkAgg backend works now. Patched the X-Server dependancy away when building
* Sat Mar 10 2007 werner.ho@gmx.de
- improved the BuildRequires list. Tkinter backend has still problems
* Wed Feb 28 2007 werner.ho@gmx.de
- new version 0.90.0
* Mon Oct 30 2006 werner.ho@gmx.de
- new version 0.87.7
* Wed Sep 27 2006 werner.ho@gmx.de
- Initial build.
